PsramVaddrMode

Enum PsramVaddrMode 

pub enum PsramVaddrMode {
    Normal = 0,
    LowHigh = 1,
    Evenodd = 2,
}
PSRAM virtual address mode.

Specifies how PSRAM is mapped for the CPU cores.

Variants



Normal = 0

App and pro CPU use their own flash cache for external RAM access.

In this mode both cores access the same physical PSRAM.



LowHigh = 1

App and pro CPU share external RAM caches: pro CPU has low * 2M, app CPU has high 2M.

In this mode the two cores will access different parts of PSRAM.



Evenodd = 2

App and pro CPU share external RAM caches: pro CPU does even 32 byte ranges, app does odd ones.

In this mode the two cores will access different parts of PSRAM.